@@ -1,7 +1,6 @@
 from __future__ import absolute_import
-from .web import *
-
+from solox.web import main
+import fire as fire
 
 if __name__ == '__main__':
-    main()
-
+    fire.Fire(main)
